Index: channels/chan_skinny.c
===================================================================
--- channels/chan_skinny.c	(revision 381255)
+++ channels/chan_skinny.c	(working copy)
@@ -1094,6 +1094,13 @@
 	char calldetails[MAXCALLINFOSTR];
 };
 
+#define DISPLAY_PROMPT_NUMBER_MESSAGE_VARIABLE 0x0144
+struct display_prompt_number_message_variable {
+	uint32_t unknown1;
+	uint32_t unknown2;
+	char dialingNumber[MAXCALLINFOSTR];
+};
+
 #define DISPLAY_PROMPT_STATUS_MESSAGE_VARIABLE 0x0145
 struct display_prompt_status_message_variable {
 	uint32_t unknown;
@@ -1152,6 +1159,7 @@
 	struct bksp_req_message bkspmessage;
 	struct call_info_message_variable callinfomessagevariable;
 	struct display_prompt_status_message_variable displaypromptstatusvar;
+	struct display_prompt_number_message_variable displaypromptnumbervar;
 };
 
 /* packet composition */
@@ -2738,6 +2746,30 @@
 	transmit_response(d, req);
 }
 
+static void transmit_displaypromptnumbervar(struct skinny_device *d, const char *text, const char *extratext, int t, int instance, int callid)
+{
+	struct skinny_req *req;
+	int packetlen;
+	int octalstrlen = strlen(text);
+
+	if (!(req = req_alloc(sizeof(struct display_prompt_number_message_variable), DISPLAY_PROMPT_NUMBER_MESSAGE_VARIABLE)))
+		return;
+
+	req->data.displaypromptnumbervar.unknown1 = htolel(10); // 0x0a timeout for display
+	req->data.displaypromptnumbervar.unknown2 = htolel(5); // 0x05 possible priority
+
+	ast_copy_string(req->data.displaypromptnumbervar.dialingNumber, text, sizeof(req->data.displaypromptnumbervar.dialingNumber));
+	ast_copy_string(req->data.displaypromptnumbervar.dialingNumber+octalstrlen, extratext, sizeof(req->data.displaypromptnumbervar.dialingNumber)-octalstrlen);
+	packetlen = req->len - MAXCALLINFOSTR + strlen(text) + strlen(extratext);
+
+	SKINNY_DEBUG(DEBUG_PACKET, 3, "Transmitting DISPLAY_PROMPT_NUMBER_MESSAGE_VARIABLE to %s, '\\%03o\\%03o', '%s'\n",
+		d->name, (uint8_t)*text, (uint8_t)*(text+1), extratext);
+
+	req->len = (packetlen & ~0x3) + 4;
+
+	transmit_response(d, req);
+}
+
 static void transmit_displaypromptstatusvar(struct skinny_device *d, const char *text, const char *extratext, int t, int instance, int callid)
 {
 	struct skinny_req *req;
@@ -5457,6 +5489,7 @@
 		transmit_callstate(d, l->instance, sub->callid, SKINNY_RINGIN);
 		transmit_selectsoftkeys(d, l->instance, sub->callid, KEYDEF_RINGIN, KEYMASK_ALL);
 		send_displaypromptstatus(d, "Ring-In", "", 0, l->instance, sub->callid);
+		transmit_displaypromptnumbervar(d, OCTAL_FROM, S_COR(ast_channel_connected(c)->id.number.valid, ast_channel_connected(c)->id.number.str, "Unknown"), 0, l->instance, sub->callid);
 		send_callinfo(sub);
 		transmit_lamp_indication(d, STIMULUS_LINE, l->instance, SKINNY_LAMP_BLINK);
 		transmit_ringer_mode(d, SKINNY_RING_INSIDE);
